![PyPI - Python Version](https://img.shields.io/pypi/pyversions/wagtail-cjkcms)
[![GitHub license](https://img.shields.io/github/license/cjkpl/wagtail-cjkcms)](https://github.com/cjkpl/wagtail-cjkcms/blob/main/LICENSE)
[![GitHub issues](https://img.shields.io/github/issues/cjkpl/wagtail-cjkcms)](https://github.com/cjkpl/wagtail-cjkcms/issues) 
[![Documentation Status](https://readthedocs.org/projects/cjkcms/badge/?version=latest)](https://cjkcms.readthedocs.io/en/latest/?badge=latest)

CMS system for Wagtail 5.x, Django 4.x and 5.x, with support for Bootstrap 5.x and MDBootstrap 5.x. 

## Summary

Out of the box, CjkCMS provides your project with generic, reusable pages:
`[Project] ArticleIndex`, `[Project] Article`, `[Project] WebPage` which you can use in your project, or easily extend with additional functionality by defining new blocks from scratch, or installing any Wagtail application that defines new blocks. 

CjkCMS pages provide you with an ultra-flexible, generic "body" section and, using `wagtail-seo` package, a basic SEO functionality.

## Homepage
Project homepage, with demos, examples and documentation: [https://cjkcms.com/](https://cjkcms.com/)

## Documentation
Direct link to the documentation: [Docs](https://cjkcms.readthedocs.io/en/latest/)

## Beginnings
CjkCMS was forked from, and is based on [Wagtail CRX](https://github.com/coderedcorp/coderedcms) - an excellent CMS by [CodeRed](https://www.coderedcorp.com/).

## Contact & support
Please use [Github's Issue Tracker](https://github.com/cjkpl/wagtail-cjkcms/issues) to report bugs, request features, or request support.